@@ -1,3 +1,4 @@
+from typing import Optional
 from .action import NHCAction
 
 class NHCLight(NHCAction):
@@ -7,9 +8,12 @@ class NHCLight(NHCAction):
         """Is on."""
         return self._state > 0
 
-    async def turn_on(self, brightness=255) -> None:
+    async def turn_on(self, brightness: Optional[int] = None) -> None:
         """Turn On."""
         if (self.is_dimmable):
+            #make sure brightness is passed when turning on a dimmable light using toggle
+            if (brightness is None) :
+                brightness = self._state if self._state > 0 else 255
             await self._controller.execute(self.id, round(brightness / 2.55))
         else:
             await self._controller.execute(self.id, brightness)
